@@ -16,21 +16,19 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
+#include <roken.h>
 
-
-#include <string.h>
-
-#include "fsprobe.h"		/*Interface for this module */
 #include <lwp.h>		/*Lightweight process package */
 #include <afs/cellconfig.h>
 #include <afs/afsint.h>
 #include <afs/afsutil.h>
 #include <afs/volser.h>
 #include <afs/volser_prototypes.h>
-
 #define FSINT_COMMON_XG
 #include <afs/afscbint.h>
 
+#include "fsprobe.h"		/*Interface for this module */
+
 #define LWP_STACK_SIZE	(16 * 1024)
 
 /*
@@ -51,6 +49,14 @@ static PROCESS probeLWP_ID;	/*Probe LWP process ID */
 static int fsprobe_statsBytes;	/*Num bytes in stats block */
 static int fsprobe_probeOKBytes;	/*Num bytes in probeOK block */
 
+/*
+ * We have to pass a port to Rx to start up our callback listener
+ * service, but 7001 is already taken up by the Cache Manager.  So,
+ * we make up our own.
+ */
+#define FSPROBE_CBPORT	7101
+
+
 /*------------------------------------------------------------------------
  * [private] fsprobe_CleanupInit
  *
@@ -225,7 +231,6 @@ fsprobe_LWP(void *unused)
     struct ProbeViceStatistics *curr_stats;	/*Current stats region */
     int *curr_probeOK;		/*Current probeOK field */
     ViceStatistics64 stats64;      /*Current stats region */
-    stats64.ViceStatistics64_len = STATS64_VERSION;
     stats64.ViceStatistics64_val = (afs_uint64 *)malloc(STATS64_VERSION *
 							sizeof(afs_uint64));
     while (1) {			/*Service loop */
@@ -484,6 +489,7 @@ fsprobe_Init(int a_numServers, struct sockaddr_in *a_socketArray,
     struct fsprobe_ConnectionInfo *curr_conn;	/*Ptr to current conn */
     char *hostNameFound;	/*Ptr to returned host name */
     int conn_err;		/*Connection error? */
+    int PortToUse;		/*Callback port to use */
 
     /*
      * If we've already been called, snicker at the bozo, gently
@@ -588,13 +594,24 @@ fsprobe_Init(int a_numServers, struct sockaddr_in *a_socketArray,
      */
     if (fsprobe_debug)
 	fprintf(stderr, "[%s] Initializing Rx\n", rn);
-    code = rx_Init(0);
-    if (code) {
-	fprintf(stderr, "[%s] Fatal error in rx_Init()\n", rn);
-	return (-1);
-    }
+    PortToUse = FSPROBE_CBPORT;
+    do {
+	code = rx_Init(htons(PortToUse));
+	if (code) {
+	    if (code == RX_ADDRINUSE) {
+		if (fsprobe_debug)
+		    fprintf(stderr,
+			    "[%s] Callback port %d in use, advancing\n", rn,
+			    PortToUse);
+		PortToUse++;
+	    } else {
+		fprintf(stderr, "[%s] Fatal error in rx_Init()\n", rn);
+		return (-1);
+	    }
+	}
+    } while (code);
     if (fsprobe_debug)
-	fprintf(stderr, "[%s] Rx initialized.\n", rn);
+	fprintf(stderr, "[%s] Rx initialized on port %d\n", rn, PortToUse);
 
     /*
      * Create a null Rx server security object, to be used by the
